"use client";

import { useId } from "react";

import { format } from "date-fns";
import { CalendarIcon } from "lucide-react";
import { useTranslations } from "next-intl";
import { Controller } from "react-hook-form";

import { Button } from "@/components/ui/button";
import { Calendar } from "@/components/ui/calendar";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover";
import { cn } from "@/lib/utils";

import { DateFieldProps } from "../types/all-fields";

const DateField = <T,>({
  name,
  control,
  required = false,
  placeholder,
  containerClassName,
  labelClassName,
  errorClassName,
  onChange,
  label,
  variant = "outline",
  ...calendarProps
}: DateFieldProps<T>) => {
  const t = useTranslations();
  const id = useId();

  return (
    <Controller
      name={name}
      control={control}
      render={({ field, fieldState: { error } }) => (
        <div
          className={cn(
            "col-span-12 w-full space-y-2",
            containerClassName,
            variant === "under_line" && "w-auto space-y-0"
          )}
        >
          <label
            htmlFor={id}
            className={cn(
              "text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70",
              labelClassName
            )}
          >
            {label || name}
            {required && <span className="ml-1 text-red-500">{"*"}</span>}
          </label>

          <Popover>
            <PopoverTrigger asChild>
              <Button
                variant={"default"}
                className={cn(
                  "w-full justify-start text-left font-normal",
                  !field.value && "text-muted-foreground",
                  variant === "under_line" &&
                    "!mt-3 rounded-none border-b border-l-0 border-r-0 border-t-0 border-primary bg-transparent px-0 text-white hover:bg-transparent",
                  variant === "transparent" &&
                    "bg-transparent hover:bg-transparent",
                  variant === "default" && "bg-gray-100 hover:bg-gray-200",
                  variant === "outline" && "border-2 border-gray-300",
                  variant === "ghost" && "bg-transparent hover:bg-transparent"
                )}
              >
                <CalendarIcon className="mr-2 h-4 w-4" />
                {field.value ? (
                  format(field.value, "PPP")
                ) : (
                  <span>{placeholder || t("Pick a date")}</span>
                )}
              </Button>
            </PopoverTrigger>
            <PopoverContent className="w-auto p-0" align="start">
              <Calendar
                mode="single"
                selected={field.value}
                onSelect={(date) => {
                  field.onChange(date);
                  if (onChange) onChange(date);
                }}
                initialFocus
                {...calendarProps}
              />
            </PopoverContent>
          </Popover>

          {error && (
            <span className={cn("text-sm text-red-500", errorClassName)}>
              {error.message}
            </span>
          )}
        </div>
      )}
    />
  );
};

export default DateField;
